/*
 *--------------------------------------------------------------------
 *
 * TBinarySignal.h
 *
 * A class wrapper for a Posix condition variable.
 * NOTE: Error handling does not yet exist.
 *
 * Copyright (c) 2001 Kreatel Communications AB. All Rights Reserved.
 *
 *--------------------------------------------------------------------
 */

#ifndef TBINARYSIGNAL_H
#define TBINARYSIGNAL_H

#include <pthread.h>

class TBinarySignal
{
protected:
  pthread_cond_t ConditionVariable;
  pthread_mutex_t Mutex;
  bool ConditionFlag;

public:
  TBinarySignal();
  ~TBinarySignal();

  void Signal();
  void Wait();
  void Wait(int timeout);  // Timeout is specified in milliseconds.
};

inline TBinarySignal::TBinarySignal()
{
  pthread_cond_init(&ConditionVariable, NULL);
  pthread_mutex_init(&Mutex, NULL);
  ConditionFlag = false;
}

inline TBinarySignal::~TBinarySignal()
{
  pthread_mutex_destroy(&Mutex);
  pthread_cond_destroy(&ConditionVariable);
}

inline void TBinarySignal::Signal()
{
  ::pthread_mutex_lock(&Mutex);
  ConditionFlag = true;
  ::pthread_cond_signal(&ConditionVariable);
  ::pthread_mutex_unlock(&Mutex);
}

inline void TBinarySignal::Wait()
{
  ::pthread_mutex_lock(&Mutex);
  while (!ConditionFlag) {
    ::pthread_cond_wait(&ConditionVariable, &Mutex);
  }
  ConditionFlag = false;
  ::pthread_mutex_unlock(&Mutex);
}

inline void TBinarySignal::Wait(int timeout)
{
  timespec t;
  t.tv_sec = timeout / 1000;  // Seconds.
  t.tv_nsec = (timeout % 1000) * 1000 * 1000;  // Nanoseconds.

  ::pthread_mutex_lock(&Mutex);
  while (!ConditionFlag) {
    ::pthread_cond_timedwait(&ConditionVariable, &Mutex, &t);
  }
  ConditionFlag = false;
  ::pthread_mutex_unlock(&Mutex);
}

#endif
