/*
 *--------------------------------------------------------------------
 *
 * TException.h
 *
 * An exception base class
 *
 * Copyright (c) 1996-2000 Kreatel Communications AB
 *
 *--------------------------------------------------------------------
 */

#ifndef TEXCEPTION_H
#define TEXCEPTION_H

// ----------------------------------------------------------------------------
// TException
// Basic exception class.

class TException
{
protected:
  const char* Message;

public:
  TException(const char* message) throw ();

  // virtual enables RTTI, necessary with exception hierarchies.
  virtual ~TException() throw ();
  virtual const char* GetText() const throw ();
};



// ----------------------------------------------------------------------------
// TBadCastException 
// General bad cast exception.

class TBadCastException : public TException
{
public:
  TBadCastException(const char* message = NULL) throw ();
};


// ----------------------------------------------------------------------------
// TBadCastException 
// General null reference exception.

class TNullReferenceException : public TException
{
public:
  TNullReferenceException(const char* message = NULL) throw ();

};


// ----------------------------------------------------------------------------
// TBadCastException
// General I/O exception.

class TIOException : public TException
{
public:
  TIOException(const char* message = NULL) throw ();
};


// ----------------------------------------------------------------------------
// TBadCastException
// General not found exception.

class TNotFoundException : public TException
{
public:
  TNotFoundException(const char* message = NULL) throw ();
};

// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
// Inlined methods
// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------

// ----------------------------------------------------------------------------
// TException

inline
TException::TException(const char* message) throw ()
  : Message(message)
{
  // empty
}

inline
TException::~TException() throw ()
{
  // empty
}

inline const char*
TException::GetText() const throw ()
{
  return Message;
}


// ----------------------------------------------------------------------------
// TBadCastException

inline
TBadCastException::TBadCastException(const char* message) throw ()
  : TException(message)
{
  // empty
}


// ----------------------------------------------------------------------------
// TNullReferenceException

inline
TNullReferenceException::TNullReferenceException(const char* message) throw ()
  : TException(message)
{
  // empty
}


// ----------------------------------------------------------------------------
// TIOException

inline
TIOException::TIOException(const char* message) throw ()
  : TException(message)
{
  // empty
}


// ----------------------------------------------------------------------------
// TNotFoundException

inline
TNotFoundException::TNotFoundException(const char* message) throw ()
  : TException(message)
{
  // empty
}

#endif
