/*
 *--------------------------------------------------------------------
 *
 * TVerboseException.h
 *
 * An exception class with verbose exception information. The class is
 * completely self-contained and has no references to other memory.
 *
 * Copyright (c) 1998 Kreatel Communications AB
 *
 *--------------------------------------------------------------------
 */

#ifndef TVERBOSEEXCEPTION_H
#define TVERBOSEEXCEPTION_H

#include "TException.h"
#include <string>

class TVerboseException : public TException
{
protected:
  int Code;
  std::string Text;

public:
  TVerboseException(int code) throw ();
  TVerboseException( const char* message, int code = 0) throw ();
  TVerboseException(const std::string& message, int code = 0) throw ();

  int GetCode() const throw ();
  const std::string& GetString() const throw ();
  virtual const char* GetText() const throw ();
};

inline TVerboseException::TVerboseException(int code) throw ()
  : TException(NULL),
    Code(code)
{
  // Empty constructor body.
}

inline TVerboseException::TVerboseException(const char* message, int code) throw ()
  : TException(message),
    Code(code),
    Text(message)
{
  // Empty constructor body.
}

inline TVerboseException::TVerboseException(const std::string& message, int code)
  throw ()
  : TException(NULL),
    Code(code),
    Text(message)
{
  // Empty constructor body.
}

inline int TVerboseException::GetCode() const throw ()
{
  return Code;
}

inline const std::string& TVerboseException::GetString() const throw ()
{
  return Text;
}

inline const char* TVerboseException::GetText() const throw ()
{
  return Text.c_str();
}

#endif
