/*
 *--------------------------------------------------------------------
 *
 * memtester.cpp
 *
 * Heap memory test program. Tests thread safety of the memory allocator.
 *
 * Copyright (c) 2001 Kreatel Communications AB. All Rights Reserved.
 *
 *--------------------------------------------------------------------
 */

#include <iostream>
#include <iomanip>
#include "TDetachThread.h"
#include "TBinarySignal.h"

// This is the approximate size of the allocated block of heap memory.
// Empirical studies indicate that this number does not have a noticable
// impact on the crash rate of the program.
#define TEST_BLOCK_SIZE 1203

class TSecondThread : public TDetachThread
{
private:
  TBinarySignal* Signal;
  char MemoryBlock[TEST_BLOCK_SIZE];

protected:
  // Overloads pure virtual function in base class.
  virtual void Execute() throw ();

public:
  TSecondThread(TBinarySignal& signal);
};

TSecondThread::TSecondThread(TBinarySignal& signal)
{
  Signal = &signal;
}

void TSecondThread::Execute() throw ()
{
  TBinarySignal* s = Signal;
  delete this;

  s->Signal();
}

void main(int argc, char* argv[])
{
  std::cout << "memetester: Heap memory test program\n"
            << "Tests thread safety of the memory allocator.\n"
            << "[Cancel test with Ctrl-C]\n";

  TBinarySignal signal;

  while (true) {
    TSecondThread* secondThread = new TSecondThread(signal);
    secondThread->Start();
    signal.Wait();

    std::cerr << '.';
  }
}
